<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:i6="http://iuclid6.echa.europa.eu/namespaces/platform-fields/v1" xmlns:i6c="http://iuclid6.echa.europa.eu/namespaces/platform-container/v1" xmlns:xt="http://iuclid6.echa.europa.eu/namespaces/ENDPOINT_STUDY_RECORD-ToxicityToTerrestrialArthropods/2.0" version="1.0">
    <xsl:template match="/">
        <html>
            <head>
                <link href="iuclid6_style.css" rel="stylesheet" type="text/css"/>
            </head>
            <body>
                <table>
                    <tr/>
                    <xsl:apply-templates/>
                </table>
            </body>
        </html>
    </xsl:template>
    <xsl:template match="//i6c:PlatformMetadata | //i6c:Attachments | //i6c:ModificationHistory"/>
    <xsl:template match="//xt:ENDPOINT_STUDY_RECORD">
        <tr class="headerDocument">
            <td>Toxicity to terrestrial arthropods</td>
            <td>
                <hr/>
            </td>
        </tr>
        <xsl:apply-templates select="./@*"/>
        <xsl:apply-templates/>
    </xsl:template>
    <xsl:template match="//xt:RobustStudy | //xt:UsedForClassification | //xt:UsedForMSDS | //xt:KeyResult">
        <tr>
            <td class="label">
                <xsl:choose>
                    <xsl:when test="name(.) = 'RobustStudy'">Robust study summary</xsl:when>
                    <xsl:when test="name(.) = 'UsedForMSDS'">Used for SDS</xsl:when>
                    <xsl:when test="name(.) = 'UsedForClassification'">Used for classification</xsl:when>
                    <xsl:when test="name(.) = 'KeyResult'">Key result</xsl:when>
                </xsl:choose>
            </td>
            <td class="value">
                <xsl:value-of select=". "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:DataProtection">
        <tr>
            <td class="label"/>
            <td class="value">
                <xsl:apply-templates/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:RelatedInformation | //xt:TestMaterialInformation">
        <tr>
            <td class="label">
                <xsl:choose>
                    <xsl:when test="name(.) = 'RelatedInformation'">Related information</xsl:when>
                    <xsl:when test="name(.) = 'TestMaterialInformation'">Test material information</xsl:when>
                </xsl:choose>
            </td>
            <td class="value">
                <xsl:value-of select=". "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:TotalExposureDuration | //xt:Duration">
        <tr>
            <td class="label">
                <xsl:choose>
                    <xsl:when test="name(.) = 'TotalExposureDuration'">Total exposure duration</xsl:when>
                    <xsl:when test="name(.) = 'Duration'">Duration</xsl:when>
                </xsl:choose>
            </td>
            <td class="value">
                <xsl:value-of select="./i6:value "/>
                <xsl:choose>
                    <xsl:when test="./i6:unitCode = '2113'"> min</xsl:when>
                    <xsl:when test="./i6:unitCode = '1976'"> h</xsl:when>
                    <xsl:when test="./i6:unitCode = '1839'"> d</xsl:when>
                    <xsl:when test="./i6:unitCode = '2468'"> wk</xsl:when>
                    <xsl:when test="./i6:unitCode = '2133'"> mo</xsl:when>
                </xsl:choose>
                <xsl:value-of select="./i6:unitOther "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:EffectConc">
        <tr>
            <td class="label">Effect conc.</td>
            <td class="value">
                <xsl:value-of select="./i6:lowerQualifier "/>
                <xsl:value-of select="./i6:lowerValue "/>
                <xsl:value-of select="./i6:upperQualifier "/>
                <xsl:value-of select="./i6:upperValue "/>
                <xsl:choose>
                    <xsl:when test="./i6:unitCode = '8089'"> ng/kg soil dw</xsl:when>
                    <xsl:when test="./i6:unitCode = '8088'"> µg/kg soil dw</xsl:when>
                    <xsl:when test="./i6:unitCode = '2096'"> mg/kg soil dw</xsl:when>
                    <xsl:when test="./i6:unitCode = '8126'"> ng/kg soil ww</xsl:when>
                    <xsl:when test="./i6:unitCode = '8127'"> µg/kg soil ww</xsl:when>
                    <xsl:when test="./i6:unitCode = '8128'"> mg/kg soil ww</xsl:when>
                    <xsl:when test="./i6:unitCode = '2495'"> µg per animal</xsl:when>
                    <xsl:when test="./i6:unitCode = '1930'"> g/ha</xsl:when>
                    <xsl:when test="./i6:unitCode = '2118'"> mL/ha</xsl:when>
                    <xsl:when test="./i6:unitCode = '2081'"> mg/kg bw</xsl:when>
                    <xsl:when test="./i6:unitCode = '2090'"> mg/kg diet</xsl:when>
                    <xsl:when test="./i6:unitCode = '2283'"> ppm</xsl:when>
                    <xsl:when test="./i6:unitCode = '2077'"> mg/cm²</xsl:when>
                    <xsl:when test="./i6:unitCode = '62028'"> mg/kg dung dw</xsl:when>
                    <xsl:when test="./i6:unitCode = '1342'"> other:</xsl:when>
                </xsl:choose>
                <xsl:value-of select="./i6:unitOther "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:DataWaivingJustification">
        <tr>
            <td class="label">Justification for data waiving</td>
            <td class="value">
                <xsl:choose>
                    <xsl:when test="./i6:value = '61065'">the study does not need to be conducted because direct and indirect exposure of the soil compartment is unlikely</xsl:when>
                    <xsl:when test="./i6:value = '61066'">a short-term study does not need to be conducted because an appropriate long-term toxicity study on terrestrial organisms is available</xsl:when>
                    <xsl:when test="./i6:value = '1342'">other:</xsl:when>
                </xsl:choose>
                <xsl:value-of select="./i6:other "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:Endpoint | //xt:StudyResultType | //xt:PurposeFlag | //xt:Reliability | //xt:RationalReliability | //xt:DataWaiving | //xt:ReasonPurpose | //xt:ReasonPurpose | //xt:DataAccess | //xt:DataProtectionClaimed | //xt:Qualifier | //xt:Guideline | //xt:Deviation | //xt:GLPComplianceStatement | //xt:ApplicationMethod | //xt:AnalyticalMonitoring | //xt:Vehicle | //xt:TestOrganismsSpecies | //xt:AnimalGroup | //xt:StudyType | //xt:LimitTest | //xt:ReferenceSubstancePositiveControl | //xt:Endpoint | //xt:NominalMeasured | //xt:ConcBasedOn | //xt:BasisForEffect | //xt:RemarksOnResults | //xt:ValidityCriteriaFulfilled">
        <tr>
            <td class="label">
                <xsl:choose>
                    <xsl:when test="name(.) = 'AnalyticalMonitoring'">Analytical monitoring</xsl:when>
                    <xsl:when test="name(.) = 'DataWaiving'">Data waiving</xsl:when>
                    <xsl:when test="name(.) = 'PurposeFlag'">Adequacy of study</xsl:when>
                    <xsl:when test="name(.) = 'DataAccess'">Data access</xsl:when>
                    <xsl:when test="name(.) = 'Vehicle'">Vehicle</xsl:when>
                    <xsl:when test="name(.) = 'Endpoint'">Dose descriptor</xsl:when>
                    <xsl:when test="name(.) = 'RemarksOnResults'">Remarks on result</xsl:when>
                    <xsl:when test="name(.) = 'RationalReliability'">Rationale for reliability incl. deficiencies</xsl:when>
                    <xsl:when test="name(.) = 'DataProtectionClaimed'">Data protection claimed</xsl:when>
                    <xsl:when test="name(.) = 'Qualifier'">Qualifier</xsl:when>
                    <xsl:when test="name(.) = 'ApplicationMethod'">Application method</xsl:when>
                    <xsl:when test="name(.) = 'StudyType'">Study type</xsl:when>
                    <xsl:when test="name(.) = 'ConcBasedOn'">Conc. based on</xsl:when>
                    <xsl:when test="name(.) = 'NominalMeasured'">Nominal / measured</xsl:when>
                    <xsl:when test="name(.) = 'LimitTest'">Limit test</xsl:when>
                    <xsl:when test="name(.) = 'Guideline'">Guideline</xsl:when>
                    <xsl:when test="name(.) = 'BasisForEffect'">Basis for effect</xsl:when>
                    <xsl:when test="name(.) = 'ReasonPurpose'">Reason / purpose</xsl:when>
                    <xsl:when test="name(.) = 'GLPComplianceStatement'">GLP compliance</xsl:when>
                    <xsl:when test="name(.) = 'ValidityCriteriaFulfilled'">Validity criteria fulfilled</xsl:when>
                    <xsl:when test="name(.) = 'AnimalGroup'">Animal group</xsl:when>
                    <xsl:when test="name(.) = 'TestOrganismsSpecies'">Test organisms (species)</xsl:when>
                    <xsl:when test="name(.) = 'ReferenceSubstancePositiveControl'">Reference substance (positive control)</xsl:when>
                    <xsl:when test="name(.) = 'Reliability'">Reliability</xsl:when>
                    <xsl:when test="name(.) = 'Deviation'">Deviations</xsl:when>
                    <xsl:when test="name(.) = 'StudyResultType'">Type of information</xsl:when>
                </xsl:choose>
            </td>
            <td class="value">
                <xsl:choose>
                    <xsl:when test="./i6:value = '61067'">toxicity to terrestrial arthropods: short-term</xsl:when>
                    <xsl:when test="./i6:value = '61068'">toxicity to terrestrial arthropods: long-term</xsl:when>
                    <xsl:when test="./i6:value = '61069'">toxicity to terrestrial arthropods, other</xsl:when>
                    <xsl:when test="./i6:value = '61982'">toxicity to terrestrial arthropods</xsl:when>
                    <xsl:when test="./i6:value = '1895'">experimental study</xsl:when>
                    <xsl:when test="./i6:value = '1896'">experimental study planned</xsl:when>
                    <xsl:when test="./i6:value = '60002'">experimental study planned (based on read-across)</xsl:when>
                    <xsl:when test="./i6:value = '14'">(Q)SAR</xsl:when>
                    <xsl:when test="./i6:value = '1885'">calculation (if not (Q)SAR)</xsl:when>
                    <xsl:when test="./i6:value = '2303'">read-across based on grouping of substances (category approach)</xsl:when>
                    <xsl:when test="./i6:value = '62036'">migrated information: read-across based on grouping of substances (category approach)</xsl:when>
                    <xsl:when test="./i6:value = '2304'">read-across from supporting substance (structural analogue or surrogate)</xsl:when>
                    <xsl:when test="./i6:value = '62035'">migrated information: read-across from supporting substance (structural analogue or surrogate)</xsl:when>
                    <xsl:when test="./i6:value = '2207'">not specified</xsl:when>
                    <xsl:when test="./i6:value = '1342'">other:</xsl:when>
                    <xsl:when test="./i6:value = '1173'">no data</xsl:when>
                    <xsl:when test="./i6:value = '921'">key study</xsl:when>
                    <xsl:when test="./i6:value = '1590'">supporting study</xsl:when>
                    <xsl:when test="./i6:value = '1661'">weight of evidence</xsl:when>
                    <xsl:when test="./i6:value = '8108'">disregarded due to major methodological deficiencies</xsl:when>
                    <xsl:when test="./i6:value = '60020'">other information</xsl:when>
                    <xsl:when test="./i6:value = '16'">1 (reliable without restriction)</xsl:when>
                    <xsl:when test="./i6:value = '18'">2 (reliable with restrictions)</xsl:when>
                    <xsl:when test="./i6:value = '22'">3 (not reliable)</xsl:when>
                    <xsl:when test="./i6:value = '24'">4 (not assignable)</xsl:when>
                    <xsl:when test="./i6:value = '60170'">guideline study</xsl:when>
                    <xsl:when test="./i6:value = '60171'">comparable to guideline study</xsl:when>
                    <xsl:when test="./i6:value = '60172'">test procedure in accordance with national standard methods</xsl:when>
                    <xsl:when test="./i6:value = '60173'">test procedure in accordance with generally accepted scientific standards and described in sufficient detail</xsl:when>
                    <xsl:when test="./i6:value = '60174'">guideline study without detailed documentation</xsl:when>
                    <xsl:when test="./i6:value = '60175'">guideline study with acceptable restrictions</xsl:when>
                    <xsl:when test="./i6:value = '60176'">comparable to guideline study with acceptable restrictions</xsl:when>
                    <xsl:when test="./i6:value = '60177'">test procedure in accordance with national standard methods with acceptable restrictions</xsl:when>
                    <xsl:when test="./i6:value = '60178'">study well documented, meets generally accepted scientific principles, acceptable for assessment</xsl:when>
                    <xsl:when test="./i6:value = '60179'">accepted calculation method</xsl:when>
                    <xsl:when test="./i6:value = '60180'">data from handbook or collection of data</xsl:when>
                    <xsl:when test="./i6:value = '60181'">significant methodological deficiencies</xsl:when>
                    <xsl:when test="./i6:value = '60182'">unsuitable test system</xsl:when>
                    <xsl:when test="./i6:value = '60183'">abstract</xsl:when>
                    <xsl:when test="./i6:value = '60184'">secondary literature</xsl:when>
                    <xsl:when test="./i6:value = '60185'">documentation insufficient for assessment</xsl:when>
                    <xsl:when test="./i6:value = '60186'">results derived from a valid (Q)SAR model and falling into its applicability domain, with adequate and reliable documentation / justification</xsl:when>
                    <xsl:when test="./i6:value = '60187'">results derived from a valid (Q)SAR model and falling into its applicability domain, with limited documentation / justification</xsl:when>
                    <xsl:when test="./i6:value = '60188'">results derived from a valid (Q)SAR model, but  not (completely) falling into its applicability domain, with adequate and reliable documentation / justification</xsl:when>
                    <xsl:when test="./i6:value = '60189'">results derived from a (Q)SAR model, with limited documentation / justification, but validity of model and reliability of prediction considered adequate based on a generally acknowledged source</xsl:when>
                    <xsl:when test="./i6:value = '60190'">results derived from a valid (Q)SAR model, but not (completely) falling into its applicability domain, and documentation / justification is limited</xsl:when>
                    <xsl:when test="./i6:value = '60191'">results derived from a (Q)SAR model, with limited documentation / justification</xsl:when>
                    <xsl:when test="./i6:value = '1588'">study technically not feasible</xsl:when>
                    <xsl:when test="./i6:value = '1587'">study scientifically not necessary / other information available</xsl:when>
                    <xsl:when test="./i6:value = '982'">exposure considerations</xsl:when>
                    <xsl:when test="./i6:value = '60022'">study waived due to provisions of other regulation</xsl:when>
                    <xsl:when test="./i6:value = '2533'">other justification</xsl:when>
                    <xsl:when test="./i6:value = '60006'">data waiving: supporting information</xsl:when>
                    <xsl:when test="./i6:value = '60007'">exposure-related information</xsl:when>
                    <xsl:when test="./i6:value = '60008'">read-across: supporting information</xsl:when>
                    <xsl:when test="./i6:value = '60009'">(Q)SAR model reporting (QMRF)</xsl:when>
                    <xsl:when test="./i6:value = '60010'">(Q)SAR prediction reporting (QPRF)</xsl:when>
                    <xsl:when test="./i6:value = '60011'">(Q)SAR model and prediction reporting (QMRF/QPRF)</xsl:when>
                    <xsl:when test="./i6:value = '60012'">(Q)SAR: supporting information</xsl:when>
                    <xsl:when test="./i6:value = '60013'">justification, other:</xsl:when>
                    <xsl:when test="./i6:value = '60014'">assessment report</xsl:when>
                    <xsl:when test="./i6:value = '60015'">read-across source</xsl:when>
                    <xsl:when test="./i6:value = '60016'">reference to other assay used for intermediate effect derivation</xsl:when>
                    <xsl:when test="./i6:value = '60017'">reference to same study</xsl:when>
                    <xsl:when test="./i6:value = '60018'">reference to other study</xsl:when>
                    <xsl:when test="./i6:value = '1838'">data submitter is data owner</xsl:when>
                    <xsl:when test="./i6:value = '1837'">data submitter has Letter of Access</xsl:when>
                    <xsl:when test="./i6:value = '1835'">data no longer protected</xsl:when>
                    <xsl:when test="./i6:value = '1836'">data published</xsl:when>
                    <xsl:when test="./i6:value = '2193'">not applicable</xsl:when>
                    <xsl:when test="./i6:value = '60023'">data submitter has permission to refer</xsl:when>
                    <xsl:when test="./i6:value = '2480'">yes</xsl:when>
                    <xsl:when test="./i6:value = '4161'">yes, but willing to share</xsl:when>
                    <xsl:when test="./i6:value = '4162'">yes, but not willing to share</xsl:when>
                    <xsl:when test="./i6:value = '1680'">according to</xsl:when>
                    <xsl:when test="./i6:value = '1880'">equivalent or similar to</xsl:when>
                    <xsl:when test="./i6:value = '2172'">no guideline followed</xsl:when>
                    <xsl:when test="./i6:value = '2171'">no guideline available</xsl:when>
                    <xsl:when test="./i6:value = '2175'">no guideline required</xsl:when>
                    <xsl:when test="./i6:value = '1211'">OECD Guideline 213 (Honeybees, Acute Oral Toxicity Test)</xsl:when>
                    <xsl:when test="./i6:value = '1212'">OECD Guideline 214 (Honeybees, Acute Contact Toxicity Test)</xsl:when>
                    <xsl:when test="./i6:value = '61944'">OECD Guideline 226 (Predatory Mite (Hypoaspis (Geolaelaps) Aculeifer) Reproduction Test in Soil)</xsl:when>
                    <xsl:when test="./i6:value = '61945'">OECD Guideline 228 (Determination of Developmental Toxicity of a Test Chemical to Dipteran Dung Flies (Scathophaga stercoraria L. (Scathophagidae) and Musca autumnalis De Geer (Muscidae)))</xsl:when>
                    <xsl:when test="./i6:value = '61946'">OECD Guideline 232 (Collembolan Reproduction Test in Soil)</xsl:when>
                    <xsl:when test="./i6:value = '61947'">OECD Guideline 237 (Honey bee (Apis mellifera) Larval Toxicity Test, Single Exposure)</xsl:when>
                    <xsl:when test="./i6:value = '713'">EU Method C.16 (Honeybees - Acute Oral Toxicity Test)</xsl:when>
                    <xsl:when test="./i6:value = '714'">EU Method C.17 (Honeybees - Acute Contact Toxicity Test)</xsl:when>
                    <xsl:when test="./i6:value = '390'">EPA OPP 141-1 (Honey Bee Acute Contact Toxicity)</xsl:when>
                    <xsl:when test="./i6:value = '391'">EPA OPP 141-2 (Honey Bee Toxicity of Residues on Foliage)</xsl:when>
                    <xsl:when test="./i6:value = '392'">EPA OPP 141-5 (Field Testing for Pollinators)</xsl:when>
                    <xsl:when test="./i6:value = '480'">EPA OPPTS 850.3020 (Honey Bee Acute Contact Toxicity)</xsl:when>
                    <xsl:when test="./i6:value = '481'">EPA OPPTS 850.3030 (Honey Bee Toxicity of Residues on Foliage)</xsl:when>
                    <xsl:when test="./i6:value = '482'">EPA OPPTS 850.3040 (Field Testing for Pollinators)</xsl:when>
                    <xsl:when test="./i6:value = '862'">ISO 11267 (Inhibition of Reproduction of Collembola by Soil Pollutants)</xsl:when>
                    <xsl:when test="./i6:value = '2246'">other guideline:</xsl:when>
                    <xsl:when test="./i6:value = '2158'">no</xsl:when>
                    <xsl:when test="./i6:value = '4179'">yes (incl. certificate)</xsl:when>
                    <xsl:when test="./i6:value = '1814'">contact</xsl:when>
                    <xsl:when test="./i6:value = '2227'">oral</xsl:when>
                    <xsl:when test="./i6:value = '2375'">soil</xsl:when>
                    <xsl:when test="./i6:value = '4054'">spray</xsl:when>
                    <xsl:when test="./i6:value = '62013'">dung</xsl:when>
                    <xsl:when test="./i6:value = '2203'">not required</xsl:when>
                    <xsl:when test="./i6:value = '60'">Aleochara bilineata</xsl:when>
                    <xsl:when test="./i6:value = '61'">Aleochara sp.</xsl:when>
                    <xsl:when test="./i6:value = '98'">Aphidius rhopalosiphi</xsl:when>
                    <xsl:when test="./i6:value = '99'">Apis mellifera</xsl:when>
                    <xsl:when test="./i6:value = '148'">Bembidion lampros</xsl:when>
                    <xsl:when test="./i6:value = '149'">Bembidion sp.</xsl:when>
                    <xsl:when test="./i6:value = '6607'">Brachydesmus superus</xsl:when>
                    <xsl:when test="./i6:value = '256'">Chrysoperla carnea</xsl:when>
                    <xsl:when test="./i6:value = '261'">Coccinella septempunctata</xsl:when>
                    <xsl:when test="./i6:value = '292'">Culex pipiens quinquefasciatus</xsl:when>
                    <xsl:when test="./i6:value = '293'">Culex sp.</xsl:when>
                    <xsl:when test="./i6:value = '4452'">Drosophila melanogaster</xsl:when>
                    <xsl:when test="./i6:value = '773'">Folsomia candida</xsl:when>
                    <xsl:when test="./i6:value = '62014'">Folsomia fimetaria</xsl:when>
                    <xsl:when test="./i6:value = '774'">Folsomia sp.</xsl:when>
                    <xsl:when test="./i6:value = '853'">Hypoaspis aculeifer</xsl:when>
                    <xsl:when test="./i6:value = '62015'">Isotoma anglicana</xsl:when>
                    <xsl:when test="./i6:value = '6605'">Isotoma viridis</xsl:when>
                    <xsl:when test="./i6:value = '6606'">Lithobius mutabilis</xsl:when>
                    <xsl:when test="./i6:value = '62016'">Mesaphorura macrochaeta</xsl:when>
                    <xsl:when test="./i6:value = '61948'">Musca autumnalis</xsl:when>
                    <xsl:when test="./i6:value = '1100'">Musca domestica</xsl:when>
                    <xsl:when test="./i6:value = '1101'">Musca sp.</xsl:when>
                    <xsl:when test="./i6:value = '1325'">Oniscus assellus</xsl:when>
                    <xsl:when test="./i6:value = '1326'">Oniscus sp.</xsl:when>
                    <xsl:when test="./i6:value = '1327'">Onychiurus armatus</xsl:when>
                    <xsl:when test="./i6:value = '1328'">Onychiurus sp.</xsl:when>
                    <xsl:when test="./i6:value = '1332'">Orchesella cincta</xsl:when>
                    <xsl:when test="./i6:value = '1333'">Orchesella sp.</xsl:when>
                    <xsl:when test="./i6:value = '62017'">Orthonychiurus folsomi</xsl:when>
                    <xsl:when test="./i6:value = '1335'">Orius laevigatus</xsl:when>
                    <xsl:when test="./i6:value = '1356'">Pardosa sp.</xsl:when>
                    <xsl:when test="./i6:value = '62018'">Paronychiurus kimi</xsl:when>
                    <xsl:when test="./i6:value = '6608'">Philonthus cognatus</xsl:when>
                    <xsl:when test="./i6:value = '1391'">Poecilus cupreus</xsl:when>
                    <xsl:when test="./i6:value = '1399'">Porcellus scaber</xsl:when>
                    <xsl:when test="./i6:value = '1400'">Porcellus sp.</xsl:when>
                    <xsl:when test="./i6:value = '62019'">Proisotoma minuta</xsl:when>
                    <xsl:when test="./i6:value = '1440'">Pterostichus cupreus</xsl:when>
                    <xsl:when test="./i6:value = '1441'">Pterostichus sp.</xsl:when>
                    <xsl:when test="./i6:value = '61949'">Scathophaga stercoraria</xsl:when>
                    <xsl:when test="./i6:value = '62020'">Sinella curviseta</xsl:when>
                    <xsl:when test="./i6:value = '1615'">Tomocerus sp.</xsl:when>
                    <xsl:when test="./i6:value = '1623'">Trachelipus rathkii</xsl:when>
                    <xsl:when test="./i6:value = '1624'">Trachelipus sp.</xsl:when>
                    <xsl:when test="./i6:value = '1626'">Trichogramma cacoeciae</xsl:when>
                    <xsl:when test="./i6:value = '1642'">Typhlodromus pyri</xsl:when>
                    <xsl:when test="./i6:value = '4039'">Acari (leaf-dwelling predatory mite)</xsl:when>
                    <xsl:when test="./i6:value = '4040'">Acari (soil-dwelling predatory mite)</xsl:when>
                    <xsl:when test="./i6:value = '4041'">Araneae (soil-dwelling lycosid spider)</xsl:when>
                    <xsl:when test="./i6:value = '4042'">Coleoptera (soil-dwelling carabid beetle)</xsl:when>
                    <xsl:when test="./i6:value = '4043'">Coleoptera (soil-dwelling rove beetle)</xsl:when>
                    <xsl:when test="./i6:value = '4044'">Collembola (soil-dwelling springtail)</xsl:when>
                    <xsl:when test="./i6:value = '4045'">Crustacea (soil-dwelling woodlouse)</xsl:when>
                    <xsl:when test="./i6:value = '4046'">Diptera (fruit fly (small))</xsl:when>
                    <xsl:when test="./i6:value = '4047'">Diptera (house fly)</xsl:when>
                    <xsl:when test="./i6:value = '4048'">Diptera (mosquitoe)</xsl:when>
                    <xsl:when test="./i6:value = '62022'">Diptera (muscid dung fly)</xsl:when>
                    <xsl:when test="./i6:value = '62021'">Diptera (scathophagid dung fly)</xsl:when>
                    <xsl:when test="./i6:value = '4049'">Heteroptera (leaf-dwelling predatory bug)</xsl:when>
                    <xsl:when test="./i6:value = '4050'">Homoptera (leaf-dwelling green lacewing)</xsl:when>
                    <xsl:when test="./i6:value = '4051'">Homoptera (leaf-dwelling lady bird)</xsl:when>
                    <xsl:when test="./i6:value = '4052'">Hymenoptera (honeybees)</xsl:when>
                    <xsl:when test="./i6:value = '4053'">Hymenoptera (leaf-dwelling parasitic wasp)</xsl:when>
                    <xsl:when test="./i6:value = '2026'">laboratory study</xsl:when>
                    <xsl:when test="./i6:value = '1897'">extended laboratory study</xsl:when>
                    <xsl:when test="./i6:value = '2338'">semi-field study</xsl:when>
                    <xsl:when test="./i6:value = '1907'">field study</xsl:when>
                    <xsl:when test="./i6:value = '922'">LC0</xsl:when>
                    <xsl:when test="./i6:value = '923'">LC10</xsl:when>
                    <xsl:when test="./i6:value = '926'">LC50</xsl:when>
                    <xsl:when test="./i6:value = '924'">LC100</xsl:when>
                    <xsl:when test="./i6:value = '360'">EC0</xsl:when>
                    <xsl:when test="./i6:value = '361'">EC10</xsl:when>
                    <xsl:when test="./i6:value = '365'">EC50</xsl:when>
                    <xsl:when test="./i6:value = '362'">EC100</xsl:when>
                    <xsl:when test="./i6:value = '928'">LD0</xsl:when>
                    <xsl:when test="./i6:value = '929'">LD10</xsl:when>
                    <xsl:when test="./i6:value = '931'">LD50</xsl:when>
                    <xsl:when test="./i6:value = '930'">LD100</xsl:when>
                    <xsl:when test="./i6:value = '977'">LR0</xsl:when>
                    <xsl:when test="./i6:value = '978'">LR10</xsl:when>
                    <xsl:when test="./i6:value = '980'">LR50</xsl:when>
                    <xsl:when test="./i6:value = '979'">LR100</xsl:when>
                    <xsl:when test="./i6:value = '1129'">NOEC</xsl:when>
                    <xsl:when test="./i6:value = '957'">LOEC</xsl:when>
                    <xsl:when test="./i6:value = '2178'">nominal</xsl:when>
                    <xsl:when test="./i6:value = '2002'">meas. (initial)</xsl:when>
                    <xsl:when test="./i6:value = '1941'">meas. (geom. mean)</xsl:when>
                    <xsl:when test="./i6:value = '1736'">meas. (arithm. mean)</xsl:when>
                    <xsl:when test="./i6:value = '2421'">meas. (TWA)</xsl:when>
                    <xsl:when test="./i6:value = '4038'">meas. (not specified)</xsl:when>
                    <xsl:when test="./i6:value = '1685'">acid equivalent</xsl:when>
                    <xsl:when test="./i6:value = '1884'">estimated</xsl:when>
                    <xsl:when test="./i6:value = '1758'">test mat.</xsl:when>
                    <xsl:when test="./i6:value = '60281'">test mat. (total fraction)</xsl:when>
                    <xsl:when test="./i6:value = '60282'">test mat. (dissolved fraction)</xsl:when>
                    <xsl:when test="./i6:value = '1754'">act. ingr.</xsl:when>
                    <xsl:when test="./i6:value = '60283'">act. ingr. (total fraction)</xsl:when>
                    <xsl:when test="./i6:value = '60284'">act. ingr. (dissolved fraction)</xsl:when>
                    <xsl:when test="./i6:value = '1756'">element</xsl:when>
                    <xsl:when test="./i6:value = '60285'">element (total fraction)</xsl:when>
                    <xsl:when test="./i6:value = '60286'">element (dissolved fraction)</xsl:when>
                    <xsl:when test="./i6:value = '1755'">dissolved</xsl:when>
                    <xsl:when test="./i6:value = '1757'">labile/free</xsl:when>
                    <xsl:when test="./i6:value = '2135'">mortality</xsl:when>
                    <xsl:when test="./i6:value = '2315'">reproduction</xsl:when>
                    <xsl:when test="./i6:value = '62029'">emergence</xsl:when>
                    <xsl:when test="./i6:value = '1845'">development</xsl:when>
                    <xsl:when test="./i6:value = '1949'">growth</xsl:when>
                    <xsl:when test="./i6:value = '2134'">morphology</xsl:when>
                    <xsl:when test="./i6:value = '144'">behaviour</xsl:when>
                    <xsl:when test="./i6:value = '1916'">food consumption</xsl:when>
                    <xsl:when test="./i6:value = '2254'">parasitism</xsl:when>
                    <xsl:when test="./i6:value = '2287'">predation</xsl:when>
                    <xsl:when test="./i6:value = '60206'">not determinable</xsl:when>
                    <xsl:when test="./i6:value = '60207'">not determinable because of methodological limitations</xsl:when>
                    <xsl:when test="./i6:value = '60208'">not measured/tested</xsl:when>
                </xsl:choose>
                <xsl:value-of select="./i6:other "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//xt:AttachedJustification | //xt:CrossReference | //xt:Guideline | //xt:EffectConcentrations | //xt:AttachedBackgroundMaterial">
        <tr class="headerBlock">
            <td>
                <xsl:choose>
                    <xsl:when test="name(.) = 'EffectConcentrations'">Effect concentrations</xsl:when>
                    <xsl:when test="name(.) = 'CrossReference'">Cross-reference</xsl:when>
                    <xsl:when test="name(.) = 'Guideline'">Test guideline</xsl:when>
                    <xsl:when test="name(.) = 'AttachedJustification'">Attached justification</xsl:when>
                    <xsl:when test="name(.) = 'AttachedBackgroundMaterial'">Attached background material</xsl:when>
                </xsl:choose>
            </td>
            <td>
                <hr/>
            </td>
        </tr>
        <xsl:apply-templates select="./@*"/>
        <xsl:apply-templates/>
    </xsl:template>
    <xsl:template match="//xt:AdministrativeData | //xt:DataSource | //xt:MaterialsAndMethods | //xt:TestMaterials | //xt:SamplingAndAnalysis | //xt:TestSubstrate | //xt:TestOrganisms | //xt:StudyDesign | //xt:TestConditions | //xt:AnyOtherInformationOnMaterialsAndMethodsInclTables | //xt:ResultsAndDiscussion | //xt:AnyOtherInformationOnResultsInclTables | //xt:OverallRemarksAttachments | //xt:ApplicantSummaryAndConclusion">
        <tr class="headerBlock">
            <td>
                <xsl:choose>
                    <xsl:when test="name(.) = 'OverallRemarksAttachments'">Overall remarks, attachments</xsl:when>
                    <xsl:when test="name(.) = 'AdministrativeData'">Administrative data</xsl:when>
                    <xsl:when test="name(.) = 'TestSubstrate'">Test substrate</xsl:when>
                    <xsl:when test="name(.) = 'AnyOtherInformationOnResultsInclTables'">Any other information on results incl. tables</xsl:when>
                    <xsl:when test="name(.) = 'TestOrganisms'">Test organisms</xsl:when>
                    <xsl:when test="name(.) = 'StudyDesign'">Study design</xsl:when>
                    <xsl:when test="name(.) = 'DataSource'">Data source</xsl:when>
                    <xsl:when test="name(.) = 'SamplingAndAnalysis'">Sampling and analysis</xsl:when>
                    <xsl:when test="name(.) = 'TestConditions'">Test conditions</xsl:when>
                    <xsl:when test="name(.) = 'ApplicantSummaryAndConclusion'">Applicant's summary and conclusion</xsl:when>
                    <xsl:when test="name(.) = 'TestMaterials'">Test material</xsl:when>
                    <xsl:when test="name(.) = 'MaterialsAndMethods'">Materials and methods</xsl:when>
                    <xsl:when test="name(.) = 'AnyOtherInformationOnMaterialsAndMethodsInclTables'">Any other information on materials and methods incl. tables</xsl:when>
                    <xsl:when test="name(.) = 'ResultsAndDiscussion'">Results and discussion</xsl:when>
                </xsl:choose>
            </td>
            <td>
                <hr/>
            </td>
        </tr>
        <xsl:apply-templates select="./@*"/>
        <xsl:apply-templates/>
    </xsl:template>
    <xsl:template match="//xt:StudyPeriod | //xt:JustificationForTypeOfInformation | //xt:Remarks | //xt:VersionRemarks | //xt:MethodNoGuideline | //xt:SpecificDetailsOnTestMaterialUsedForTheStudy | //xt:DetailsOnSampling | //xt:DetailsOnAnalyticalMethods | //xt:DetailsOnPreparationAndApplicationOfTestSubstrate | //xt:DetailsOnTestOrganisms | //xt:Remarks | //xt:PostExposureObservationPeriod | //xt:TestTemperature | //xt:PhIfSoilStudy | //xt:Humidity | //xt:PhotoperiodAndLighting | //xt:DetailsOnTestConditions | //xt:NominalAndMeasuredConcentrations | //xt:OtherInformation | //xt:ResultsDetails | //xt:ResultsRefSubstance | //xt:Statistics | //xt:OtherInformation | //xt:RemarksOnResults | //xt:Remarks | //xt:Conclusions | //xt:ExecutiveSummary">
        <tr>
            <td class="label">
                <xsl:choose>
                    <xsl:when test="name(.) = 'DetailsOnTestOrganisms'">Details on test organisms</xsl:when>
                    <xsl:when test="name(.) = 'DetailsOnAnalyticalMethods'">Details on analytical methods</xsl:when>
                    <xsl:when test="name(.) = 'VersionRemarks'">Version / remarks</xsl:when>
                    <xsl:when test="name(.) = 'ResultsRefSubstance'">Results with reference substance (positive control)</xsl:when>
                    <xsl:when test="name(.) = 'Conclusions'">Conclusions</xsl:when>
                    <xsl:when test="name(.) = 'StudyPeriod'">Study period</xsl:when>
                    <xsl:when test="name(.) = 'PostExposureObservationPeriod'">Post exposure observation period</xsl:when>
                    <xsl:when test="name(.) = 'ResultsDetails'">Details on results</xsl:when>
                    <xsl:when test="name(.) = 'OtherInformation'"/>
                    <xsl:when test="name(.) = 'Statistics'">Reported statistics and error estimates</xsl:when>
                    <xsl:when test="name(.) = 'MethodNoGuideline'">Principles of method if other than guideline</xsl:when>
                    <xsl:when test="name(.) = 'DetailsOnSampling'">Details on sampling</xsl:when>
                    <xsl:when test="name(.) = 'TestTemperature'">Test temperature</xsl:when>
                    <xsl:when test="name(.) = 'PhotoperiodAndLighting'">Photoperiod and lighting</xsl:when>
                    <xsl:when test="name(.) = 'Remarks'">Remarks</xsl:when>
                    <xsl:when test="name(.) = 'RemarksOnResults'">Overall remarks</xsl:when>
                    <xsl:when test="name(.) = 'ExecutiveSummary'">Executive summary</xsl:when>
                    <xsl:when test="name(.) = 'DetailsOnPreparationAndApplicationOfTestSubstrate'">Details on preparation and application of test substrate</xsl:when>
                    <xsl:when test="name(.) = 'Humidity'">Humidity</xsl:when>
                    <xsl:when test="name(.) = 'NominalAndMeasuredConcentrations'">Nominal and measured concentrations</xsl:when>
                    <xsl:when test="name(.) = 'JustificationForTypeOfInformation'">Justification for type of information</xsl:when>
                    <xsl:when test="name(.) = 'SpecificDetailsOnTestMaterialUsedForTheStudy'">Specific details on test material used for the study</xsl:when>
                    <xsl:when test="name(.) = 'PhIfSoilStudy'">pH (if soil or dung study)</xsl:when>
                    <xsl:when test="name(.) = 'DetailsOnTestConditions'">Details on test conditions</xsl:when>
                </xsl:choose>
            </td>
            <td class="value">
                <xsl:value-of select=". "/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="//i6:country/i6:value">
        <xsl:choose>
            <xsl:when test=". = '3446'">Åland Islands </xsl:when>
            <xsl:when test=". = '2683'">Afghanistan </xsl:when>
            <xsl:when test=". = '2684'">Albania </xsl:when>
            <xsl:when test=". = '2685'">Algeria </xsl:when>
            <xsl:when test=". = '2686'">American Samoa </xsl:when>
            <xsl:when test=". = '2688'">Andorra </xsl:when>
            <xsl:when test=". = '2689'">Angola </xsl:when>
            <xsl:when test=". = '2690'">Anguilla </xsl:when>
            <xsl:when test=". = '2692'">Antarctica </xsl:when>
            <xsl:when test=". = '2695'">Antigua and Barbuda </xsl:when>
            <xsl:when test=". = '2696'">Argentina </xsl:when>
            <xsl:when test=". = '2697'">Armenia </xsl:when>
            <xsl:when test=". = '2698'">Aruba </xsl:when>
            <xsl:when test=". = '107'">Australia </xsl:when>
            <xsl:when test=". = '108'">Austria </xsl:when>
            <xsl:when test=". = '2701'">Azerbaijan </xsl:when>
            <xsl:when test=". = '2702'">Bahamas </xsl:when>
            <xsl:when test=". = '2703'">Bahrain </xsl:when>
            <xsl:when test=". = '2704'">Bangladesh </xsl:when>
            <xsl:when test=". = '2705'">Barbados </xsl:when>
            <xsl:when test=". = '2707'">Belarus </xsl:when>
            <xsl:when test=". = '147'">Belgium </xsl:when>
            <xsl:when test=". = '2708'">Belize </xsl:when>
            <xsl:when test=". = '2709'">Benin </xsl:when>
            <xsl:when test=". = '2710'">Bermuda </xsl:when>
            <xsl:when test=". = '2711'">Bhutan </xsl:when>
            <xsl:when test=". = '2720'">Bolivia, Plurinational State of </xsl:when>
            <xsl:when test=". = '2722'">Bosnia and Herzegovina </xsl:when>
            <xsl:when test=". = '2723'">Botswana </xsl:when>
            <xsl:when test=". = '2724'">Bouvet Island </xsl:when>
            <xsl:when test=". = '2725'">Brazil </xsl:when>
            <xsl:when test=". = '2726'">British Indian Ocean Territory </xsl:when>
            <xsl:when test=". = '2727'">Brunei Darussalam </xsl:when>
            <xsl:when test=". = '184'">Bulgaria </xsl:when>
            <xsl:when test=". = '2729'">Burkina Faso </xsl:when>
            <xsl:when test=". = '2730'">Burundi </xsl:when>
            <xsl:when test=". = '2734'">Cambodia </xsl:when>
            <xsl:when test=". = '2735'">Cameroon </xsl:when>
            <xsl:when test=". = '206'">Canada </xsl:when>
            <xsl:when test=". = '2736'">Cape Verde </xsl:when>
            <xsl:when test=". = '2746'">Cayman Islands </xsl:when>
            <xsl:when test=". = '2747'">Central African Republic </xsl:when>
            <xsl:when test=". = '2748'">Chad </xsl:when>
            <xsl:when test=". = '2749'">Chile </xsl:when>
            <xsl:when test=". = '2750'">China </xsl:when>
            <xsl:when test=". = '2751'">Christmas Island </xsl:when>
            <xsl:when test=". = '2754'">Cocos (Keeling) Islands </xsl:when>
            <xsl:when test=". = '2755'">Colombia </xsl:when>
            <xsl:when test=". = '2759'">Comoros </xsl:when>
            <xsl:when test=". = '2764'">Congo </xsl:when>
            <xsl:when test=". = '2765'">Congo, The Democratic Republic of the </xsl:when>
            <xsl:when test=". = '2769'">Cook Islands </xsl:when>
            <xsl:when test=". = '2771'">Costa Rica </xsl:when>
            <xsl:when test=". = '286'">Croatia </xsl:when>
            <xsl:when test=". = '2774'">Côte d'Ivoire </xsl:when>
            <xsl:when test=". = '2773'">Cuba </xsl:when>
            <xsl:when test=". = '304'">Cyprus </xsl:when>
            <xsl:when test=". = '307'">Czech Republic </xsl:when>
            <xsl:when test=". = '333'">Denmark </xsl:when>
            <xsl:when test=". = '2790'">Djibouti </xsl:when>
            <xsl:when test=". = '2791'">Dominica </xsl:when>
            <xsl:when test=". = '2792'">Dominican Republic </xsl:when>
            <xsl:when test=". = '2799'">Ecuador </xsl:when>
            <xsl:when test=". = '2800'">Egypt </xsl:when>
            <xsl:when test=". = '2801'">El Salvador </xsl:when>
            <xsl:when test=". = '2803'">Equatorial Guinea </xsl:when>
            <xsl:when test=". = '2804'">Eritrea </xsl:when>
            <xsl:when test=". = '754'">Estonia </xsl:when>
            <xsl:when test=". = '2805'">Ethiopia </xsl:when>
            <xsl:when test=". = '2813'">Falkland Islands (Malvinas) </xsl:when>
            <xsl:when test=". = '2815'">Faroe Islands </xsl:when>
            <xsl:when test=". = '2817'">Fiji </xsl:when>
            <xsl:when test=". = '766'">Finland </xsl:when>
            <xsl:when test=". = '779'">France </xsl:when>
            <xsl:when test=". = '2825'">French Guiana </xsl:when>
            <xsl:when test=". = '2826'">French Polynesia </xsl:when>
            <xsl:when test=". = '2827'">French Southern Territories </xsl:when>
            <xsl:when test=". = '2828'">Gabon </xsl:when>
            <xsl:when test=". = '2829'">Gambia </xsl:when>
            <xsl:when test=". = '2834'">Georgia </xsl:when>
            <xsl:when test=". = '807'">Germany </xsl:when>
            <xsl:when test=". = '2835'">Ghana </xsl:when>
            <xsl:when test=". = '2836'">Gibraltar </xsl:when>
            <xsl:when test=". = '810'">Greece </xsl:when>
            <xsl:when test=". = '2838'">Greenland </xsl:when>
            <xsl:when test=". = '2839'">Grenada </xsl:when>
            <xsl:when test=". = '2840'">Guadeloupe </xsl:when>
            <xsl:when test=". = '2841'">Guam </xsl:when>
            <xsl:when test=". = '2842'">Guatemala </xsl:when>
            <xsl:when test=". = '7818'">Guernsey </xsl:when>
            <xsl:when test=". = '2843'">Guinea </xsl:when>
            <xsl:when test=". = '2844'">Guinea-Bissau </xsl:when>
            <xsl:when test=". = '2845'">Guyana </xsl:when>
            <xsl:when test=". = '2846'">Haiti </xsl:when>
            <xsl:when test=". = '2851'">Heard Island and McDonald Islands </xsl:when>
            <xsl:when test=". = '2854'">Holy See (Vatican City State) </xsl:when>
            <xsl:when test=". = '2855'">Honduras </xsl:when>
            <xsl:when test=". = '2856'">Hong Kong </xsl:when>
            <xsl:when test=". = '845'">Hungary </xsl:when>
            <xsl:when test=". = '882'">Iceland </xsl:when>
            <xsl:when test=". = '2865'">India </xsl:when>
            <xsl:when test=". = '2866'">Indonesia </xsl:when>
            <xsl:when test=". = '2870'">Iran, Islamic Republic of </xsl:when>
            <xsl:when test=". = '2871'">Iraq </xsl:when>
            <xsl:when test=". = '911'">Ireland </xsl:when>
            <xsl:when test=". = '7819'">Isle of man </xsl:when>
            <xsl:when test=". = '2876'">Israel </xsl:when>
            <xsl:when test=". = '916'">Italy </xsl:when>
            <xsl:when test=". = '2877'">Jamaica </xsl:when>
            <xsl:when test=". = '918'">Japan </xsl:when>
            <xsl:when test=". = '7820'">Jersey </xsl:when>
            <xsl:when test=". = '2878'">Jordan </xsl:when>
            <xsl:when test=". = '2879'">Kazakhstan </xsl:when>
            <xsl:when test=". = '2880'">Kenya </xsl:when>
            <xsl:when test=". = '2881'">Kiribati </xsl:when>
            <xsl:when test=". = '2882'">Korea, Democratic People's Republic of </xsl:when>
            <xsl:when test=". = '2883'">Korea, Republic Of </xsl:when>
            <xsl:when test=". = '2884'">Kuwait </xsl:when>
            <xsl:when test=". = '2885'">Kyrgyzstan </xsl:when>
            <xsl:when test=". = '2886'">Lao People's Democratic Republic </xsl:when>
            <xsl:when test=". = '985'">Latvia </xsl:when>
            <xsl:when test=". = '2887'">Lebanon </xsl:when>
            <xsl:when test=". = '2888'">Lesotho </xsl:when>
            <xsl:when test=". = '2889'">Liberia </xsl:when>
            <xsl:when test=". = '2890'">Libyan Arab Jamahiriya </xsl:when>
            <xsl:when test=". = '2891'">Liechtenstein </xsl:when>
            <xsl:when test=". = '1024'">Lithuania </xsl:when>
            <xsl:when test=". = '1041'">Luxembourg </xsl:when>
            <xsl:when test=". = '2896'">Macao </xsl:when>
            <xsl:when test=". = '2897'">Macedonia, the former Yugoslav Republic of </xsl:when>
            <xsl:when test=". = '2898'">Madagascar </xsl:when>
            <xsl:when test=". = '2899'">Malawi </xsl:when>
            <xsl:when test=". = '2900'">Malaysia </xsl:when>
            <xsl:when test=". = '2901'">Maldives </xsl:when>
            <xsl:when test=". = '2902'">Mali </xsl:when>
            <xsl:when test=". = '1048'">Malta </xsl:when>
            <xsl:when test=". = '2904'">Marshall Islands </xsl:when>
            <xsl:when test=". = '2905'">Martinique </xsl:when>
            <xsl:when test=". = '2908'">Mauritania </xsl:when>
            <xsl:when test=". = '2909'">Mauritius </xsl:when>
            <xsl:when test=". = '2910'">Mayotte </xsl:when>
            <xsl:when test=". = '1067'">Mexico </xsl:when>
            <xsl:when test=". = '3877'">Micronesia, Federated States of </xsl:when>
            <xsl:when test=". = '2919'">Moldova, Republic of </xsl:when>
            <xsl:when test=". = '2921'">Monaco </xsl:when>
            <xsl:when test=". = '2922'">Mongolia </xsl:when>
            <xsl:when test=". = '7821'">Montenegro </xsl:when>
            <xsl:when test=". = '2924'">Montserrat </xsl:when>
            <xsl:when test=". = '2925'">Morocco </xsl:when>
            <xsl:when test=". = '2926'">Mozambique </xsl:when>
            <xsl:when test=". = '2930'">Myanmar </xsl:when>
            <xsl:when test=". = '2932'">Namibia </xsl:when>
            <xsl:when test=". = '2933'">Nauru </xsl:when>
            <xsl:when test=". = '2934'">Nepal </xsl:when>
            <xsl:when test=". = '1158'">Netherlands </xsl:when>
            <xsl:when test=". = '2935'">Netherlands Antilles </xsl:when>
            <xsl:when test=". = '2938'">New Caledonia </xsl:when>
            <xsl:when test=". = '1161'">New Zealand </xsl:when>
            <xsl:when test=". = '2939'">Nicaragua </xsl:when>
            <xsl:when test=". = '2940'">Niger </xsl:when>
            <xsl:when test=". = '2941'">Nigeria </xsl:when>
            <xsl:when test=". = '2942'">Niue </xsl:when>
            <xsl:when test=". = '2945'">Norfolk Island </xsl:when>
            <xsl:when test=". = '2946'">Northern Mariana Islands </xsl:when>
            <xsl:when test=". = '1175'">Norway </xsl:when>
            <xsl:when test=". = '2977'">Oman </xsl:when>
            <xsl:when test=". = '2984'">Pakistan </xsl:when>
            <xsl:when test=". = '2985'">Palau </xsl:when>
            <xsl:when test=". = '2986'">Palestinian Territory, occupied </xsl:when>
            <xsl:when test=". = '2987'">Panama </xsl:when>
            <xsl:when test=". = '2988'">Papua New Guinea </xsl:when>
            <xsl:when test=". = '2989'">Paraguay </xsl:when>
            <xsl:when test=". = '2994'">Peru </xsl:when>
            <xsl:when test=". = '2995'">Philippines </xsl:when>
            <xsl:when test=". = '3000'">Pitcairn </xsl:when>
            <xsl:when test=". = '1394'">Poland </xsl:when>
            <xsl:when test=". = '1401'">Portugal </xsl:when>
            <xsl:when test=". = '3027'">Puerto Rico </xsl:when>
            <xsl:when test=". = '3028'">Qatar </xsl:when>
            <xsl:when test=". = '1496'">Romania </xsl:when>
            <xsl:when test=". = '3177'">Réunion </xsl:when>
            <xsl:when test=". = '3175'">Russian Federation </xsl:when>
            <xsl:when test=". = '3176'">Rwanda </xsl:when>
            <xsl:when test=". = '7823'">Saint Barthélemy </xsl:when>
            <xsl:when test=". = '3318'">Saint Helena </xsl:when>
            <xsl:when test=". = '3319'">Saint Kitts and Nevis </xsl:when>
            <xsl:when test=". = '3320'">Saint Lucia </xsl:when>
            <xsl:when test=". = '7824'">Saint Martin </xsl:when>
            <xsl:when test=". = '3321'">Saint Pierre and Miquelon </xsl:when>
            <xsl:when test=". = '3322'">Saint Vincent and the Grenadines </xsl:when>
            <xsl:when test=". = '3323'">Samoa </xsl:when>
            <xsl:when test=". = '3324'">San Marino </xsl:when>
            <xsl:when test=". = '3325'">Sao Tome and Principe </xsl:when>
            <xsl:when test=". = '3326'">Saudi Arabia </xsl:when>
            <xsl:when test=". = '3328'">Senegal </xsl:when>
            <xsl:when test=". = '3332'">Serbia </xsl:when>
            <xsl:when test=". = '3333'">Seychelles </xsl:when>
            <xsl:when test=". = '3336'">Sierra Leone </xsl:when>
            <xsl:when test=". = '3337'">Singapore </xsl:when>
            <xsl:when test=". = '3339'">Slovakia </xsl:when>
            <xsl:when test=". = '1562'">Slovenia </xsl:when>
            <xsl:when test=". = '3340'">Solomon Islands </xsl:when>
            <xsl:when test=". = '3343'">Somalia </xsl:when>
            <xsl:when test=". = '3344'">South Africa </xsl:when>
            <xsl:when test=". = '3345'">South Georgia and the South Sandwich Islands </xsl:when>
            <xsl:when test=". = '1567'">Spain </xsl:when>
            <xsl:when test=". = '3346'">Sri Lanka </xsl:when>
            <xsl:when test=". = '3352'">Sudan </xsl:when>
            <xsl:when test=". = '3355'">Suriname </xsl:when>
            <xsl:when test=". = '3357'">Svalbard and Jan Mayen </xsl:when>
            <xsl:when test=". = '3358'">Swaziland </xsl:when>
            <xsl:when test=". = '1591'">Sweden </xsl:when>
            <xsl:when test=". = '1595'">Switzerland </xsl:when>
            <xsl:when test=". = '3359'">Syrian Arab Republic </xsl:when>
            <xsl:when test=". = '3362'">Taiwan, Province of China </xsl:when>
            <xsl:when test=". = '3363'">Tajikistan </xsl:when>
            <xsl:when test=". = '3364'">Tanzania, United Republic of </xsl:when>
            <xsl:when test=". = '3366'">Thailand </xsl:when>
            <xsl:when test=". = '3370'">Timor-Leste </xsl:when>
            <xsl:when test=". = '3371'">Togo </xsl:when>
            <xsl:when test=". = '3372'">Tokelau </xsl:when>
            <xsl:when test=". = '3373'">Tonga </xsl:when>
            <xsl:when test=". = '3393'">Trinidad and Tobago </xsl:when>
            <xsl:when test=". = '3394'">Tunisia </xsl:when>
            <xsl:when test=". = '1641'">Turkey </xsl:when>
            <xsl:when test=". = '3395'">Turkmenistan </xsl:when>
            <xsl:when test=". = '3396'">Turks and Caicos Islands </xsl:when>
            <xsl:when test=". = '3397'">Tuvalu </xsl:when>
            <xsl:when test=". = '3402'">Uganda </xsl:when>
            <xsl:when test=". = '3403'">Ukraine </xsl:when>
            <xsl:when test=". = '3406'">United Arab Emirates </xsl:when>
            <xsl:when test=". = '1651'">United Kingdom </xsl:when>
            <xsl:when test=". = '1652'">United States </xsl:when>
            <xsl:when test=". = '3407'">United States Minor Outlying Islands </xsl:when>
            <xsl:when test=". = '3410'">Uruguay </xsl:when>
            <xsl:when test=". = '3412'">Uzbekistan </xsl:when>
            <xsl:when test=". = '3414'">Vanuatu </xsl:when>
            <xsl:when test=". = '3416'">Venezuela, Bolivarian Republic of </xsl:when>
            <xsl:when test=". = '3420'">Viet Nam </xsl:when>
            <xsl:when test=". = '3421'">Virgin Islands, British </xsl:when>
            <xsl:when test=". = '3422'">Virgin Islands, U.S. </xsl:when>
            <xsl:when test=". = '3425'">Wallis And Futuna </xsl:when>
            <xsl:when test=". = '3428'">Western Sahara </xsl:when>
            <xsl:when test=". = '3433'">Yemen </xsl:when>
            <xsl:when test=". = '3434'">Zambia </xsl:when>
            <xsl:when test=". = '3435'">Zimbabwe </xsl:when>
            <xsl:when test=". = '1342'">other: </xsl:when>
            <xsl:when test=". = '2207'">not specified </xsl:when>
            <xsl:when test=". = '1173'">no data </xsl:when>
        </xsl:choose>
    </xsl:template>
    <xsl:template match="//xt:DataProtection/i6:confidentiality">
        <xsl:choose>
            <xsl:when test=". = '2732'">CBI </xsl:when>
            <xsl:when test=". = '2859'">IP </xsl:when>
            <xsl:when test=". = '3441'">no PA </xsl:when>
        </xsl:choose>
    </xsl:template>
</xsl:stylesheet>
